@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1103';
+our $VERSION = '0.1104';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -122,7 +122,7 @@ sub parse {
 
     # Are we minor or diminished?
     my $minor = $decorator =~ /[mo]/ ? 1 : 0;
-    print "NOTE: $note, CHORD: $chord, POSN: $position, ACCI: $accidental, ROMAN: $roman, DECO: $decorator, MINOR: $minor\n" if $self->verbose;
+    print "NOTE: $note, CHORD: $chord, POSN: $position, ACCI: $accidental, ROMAN: $roman, DECO: $decorator\n" if $self->verbose;
 
     # Convert the case of the roman representation based on minor or major
     if ( $self->chords ) {
@@ -139,7 +139,18 @@ sub parse {
         # Drop the minor and major part of the chord name
         $decorator =~ s/M//i;
     }
-    print "ROMAN: $roman, DECO: $decorator\n" if $self->verbose;
+
+    # Handle these unfortunate edge cases
+    $roman =~ s/#I\b/bII/;
+    $roman =~ s/#i\b/bii/;
+    $roman =~ s/#II\b/bIII/;
+    $roman =~ s/#ii\b/biii/;
+    $roman =~ s/#IV\b/bV/;
+    $roman =~ s/#iv\b/bv/;
+    $roman =~ s/#V\b/bVI/;
+    $roman =~ s/#v\b/bvi/;
+    $roman =~ s/#VI\b/bVII/;
+    $roman =~ s/#vi\b/bvii/;
 
     # A remaining note name is a bass decorator
     if ( $decorator =~ /($note_re)/ ) {
@@ -187,21 +198,12 @@ sub parse {
                 $decorator =~ s/#VI\b/bvii/i;
             }
         }
+        print "DECO: $decorator\n" if $self->verbose;
     }
 
-    $roman =~ s/#I\b/bII/;
-    $roman =~ s/#i\b/bii/;
-    $roman =~ s/#II\b/bIII/;
-    $roman =~ s/#ii\b/biii/;
-    $roman =~ s/#IV\b/bV/;
-    $roman =~ s/#iv\b/bv/;
-    $roman =~ s/#V\b/bVI/;
-    $roman =~ s/#v\b/bvi/;
-    $roman =~ s/#VI\b/bVII/;
-    $roman =~ s/#vi\b/bvii/;
-
     # Append the remaining decorator to the roman representation
     $roman .= $decorator;
+    print "FINAL ROMAN: $roman\n" if $self->verbose;
 
     return $roman;
 }
@@ -278,7 +280,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1103
+version 0.1104
 
 =head1 SYNOPSIS
 
@@ -431,10 +433,12 @@ L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 
-For example usage, check out the files F<eg/roman> and F<eg/basslines>
-in L<Music::BachChoralHarmony>.
+For example usage, check out the test files F<t/*> in this
+distribution.  Also see F<eg/roman> and F<eg/basslines> in
+L<Music::BachChoralHarmony>.
 
-L<App::MusicTools> C<vov> is the reverse of this module, and is significantly powerful.
+L<App::MusicTools> C<vov> is the reverse of this module, and is
+significantly powerful.
 
 =head1 AUTHOR
 
